Crate lexigram_core

Crate lexigram_core 

Modules

alt
char_reader
fixed_sym_table
lexer
log
macros
parser
segmap
text_span

Macros

opcode
Generates an OpCode instance.
seg
Generates a Seg (tuple of u32 values) from one or two values (characters or integers).
strip
Generates an opcode strip. A strip is made up of OpCode items separated by a comma.
utf8
Replaces a few identifiers by their codepoint value, and casts character / integer literals to u32.

Constants

CORE_PKG_NAME
CORE_PKG_VERSION

Traits

CollectJoin
This trait provides a shortcut for two commonly used iterator adapters.

Type Aliases

AltId
ID of a rule alternative. We use the same type as VarId because they’re very similar quantities.
TokenId
ID of a lexer token
VarId
ID of a nonterminal